@@ -35,21 +35,23 @@ var (
 	// errUndeployTooFewArgs is the error returned when neither --all nor args are specified on undeploy
 	errUndeployTooFewArgs = errors.New("either command line arguments or `--all` must be specified")
 
+	// errUndeployTrigPkg is the error returned when both --packages and --triggers are specified on undeploy
+	errUndeployTrigPkg = errors.New("the `--packages` and `--triggers` flags are mutually exclusive")
+
 	// languageKeywords maps the backend's runtime category names to keywords accepted as languages
 	// Note: this table has all languages for which we possess samples.  Only those with currently
 	// active runtimes will display.
 	languageKeywords map[string][]string = map[string][]string{
-		"nodejs":     {"javascript", "js"},
-		"deno":       {"deno"},
-		"go":         {"go", "golang"},
-		"java":       {"java"},
-		"php":        {"php"},
-		"python":     {"python", "py"},
-		"ruby":       {"ruby"},
-		"rust":       {"rust"},
-		"swift":      {"swift"},
-		"dotnet":     {"csharp", "cs"},
-		"typescript": {"typescript", "ts"},
+		"nodejs": {"javascript", "js", "typescript", "ts"},
+		"deno":   {"deno"},
+		"go":     {"go", "golang"},
+		"java":   {"java"},
+		"php":    {"php"},
+		"python": {"python", "py"},
+		"ruby":   {"ruby"},
+		"rust":   {"rust"},
+		"swift":  {"swift"},
+		"dotnet": {"csharp", "cs"},
 	}
 )
 
@@ -58,12 +60,12 @@ func Serverless() *Command {
 	cmd := &Command{
 		Command: &cobra.Command{
 			Use:   "serverless",
-			Short: "Develop and test serverless functions",
-			Long: `The ` + "`" + `doctl serverless` + "`" + ` commands provide an environment for developing and testing serverless functions.
-One or more local file system areas are employed, along with a 'functions namespace' in the cloud.
+			Short: "Develop, test, and deploy serverless functions",
+			Long: `The ` + "`" + `doctl serverless` + "`" + ` commands provide an environment for developing, testing, and deploying serverless functions.
+One or more local file system areas are employed, along with one or more 'functions namespaces' in the cloud.
 A one-time install of the serverless software is needed (use ` + "`" + `doctl serverless install` + "`" + ` to install the software,
-then ` + "`" + `doctl serverless connect` + "`" + ` to connect to a functions namespace provided with your account).
-Other ` + "`" + `doctl serverless` + "`" + ` commands are used to develop and test.`,
+then ` + "`" + `doctl serverless connect` + "`" + ` to connect to a functions namespace associated with your account).
+Other ` + "`" + `doctl serverless` + "`" + ` commands are used to develop, test, and deploy.`,
 			Aliases: []string{"sandbox", "sbx", "sls"},
 		},
 	}
@@ -81,8 +83,13 @@ The install operation is long-running, and a network connection is required.`,
 	CmdBuilder(cmd, RunServerlessUninstall, "uninstall", "Removes the serverless support", `Removes serverless support from `+"`"+`doctl`+"`",
 		Writer)
 
-	CmdBuilder(cmd, RunServerlessConnect, "connect", "Connects local serverless support to your functions namespace",
-		`This command connects `+"`"+`doctl serverless`+"`"+` to your functions namespace (needed for testing).`,
+	CmdBuilder(cmd, RunServerlessConnect, "connect [<hint>]", "Connects local serverless support to a functions namespace",
+		`This command connects `+"`"+`doctl serverless`+"`"+` support to a functions namespace of your choice.
+The optional argument should be a (complete or partial) match to a namespace label or id.
+If there is no argument, all namespaces are matched.  If the result is exactly one namespace,
+you are connected to it.  If there are multiple namespaces, you have an opportunity to choose
+the one you want from a dialog.  Use `+"`"+`doctl serverless namespaces`+"`"+` to create, delete, and
+list your namespaces.`,
 		Writer)
 
 	status := CmdBuilder(cmd, RunServerlessStatus, "status", "Provide information about serverless support",
@@ -101,11 +108,14 @@ Functions should be listed in `+"`"+`pkgName/fnName`+"`"+` form, or `+"`"+`fnNam
 The `+"`"+`--packages`+"`"+` flag causes arguments without slash separators to be intepreted as packages, in which case
 the entire packages are removed.`, Writer)
 	AddBoolFlag(undeploy, "packages", "p", false, "interpret simple name arguments as packages")
+	AddBoolFlag(undeploy, "triggers", "", false, "interpret all arguments as triggers")
 	AddBoolFlag(undeploy, "all", "", false, "remove all packages and functions")
+	undeploy.Flags().MarkHidden("triggers") // support is experimental at this point
 
 	cmd.AddCommand(Activations())
 	cmd.AddCommand(Functions())
 	cmd.AddCommand(Namespaces())
+	cmd.AddCommand(Triggers())
 	ServerlessExtras(cmd)
 	return cmd
 }
@@ -360,6 +370,7 @@ func showLanguageInfo(c *CmdConfig, APIHost string) error {
 func RunServerlessUndeploy(c *CmdConfig) error {
 	haveArgs := len(c.Args) > 0
 	pkgFlag, _ := c.Doit.GetBool(c.NS, "packages")
+	trigFlag, _ := c.Doit.GetBool(c.NS, "triggers")
 	all, _ := c.Doit.GetBool(c.NS, "all")
 	if haveArgs && all {
 		return errUndeployAllAndArgs
@@ -367,14 +378,28 @@ func RunServerlessUndeploy(c *CmdConfig) error {
 	if !haveArgs && !all {
 		return errUndeployTooFewArgs
 	}
+	if pkgFlag && trigFlag {
+		return errUndeployTrigPkg
+	}
+	if all && trigFlag {
+		return cleanTriggers(c)
+	}
 	if all {
 		return cleanNamespace(c)
 	}
 	var lastError error
 	errorCount := 0
+	var ctx context.Context
+	var sls do.ServerlessService
+	if trigFlag {
+		ctx = context.TODO()
+		sls = c.Serverless()
+	}
 	for _, arg := range c.Args {
 		var err error
-		if strings.Contains(arg, "/") || !pkgFlag {
+		if trigFlag {
+			err = sls.DeleteTrigger(ctx, arg)
+		} else if strings.Contains(arg, "/") || !pkgFlag {
 			err = deleteFunction(c, arg)
 		} else {
 			err = deletePackage(c, arg)
